# -*- encoding: utf-8 -*-
"""Evergreen representation of a project."""
from __future__ import absolute_import

from evergreen.base import _BaseEvergreenObject


class Project(_BaseEvergreenObject):
    """Representation of an Evergreen project."""

    def __init__(self, json, api):
        """
        Create an instance of an evergreen project.

        :param json: json representing project.
        :param api: evergreen api object.
        """
        super(Project, self).__init__(json, api)



# -*- encoding: utf-8 -*-
"""Host representation of evergreen."""
from __future__ import absolute_import

from evergreen.base import _BaseEvergreenObject


class RunningTask(_BaseEvergreenObject):
    """Representation of a running task."""

    def __init__(self, json, api):
        """
        Create an instance of a Running Task.

        :param json: json of running task.
        :param api: Evergreen API.
        """
        super(RunningTask, self).__init__(json, api)

    def get_build(self):
        """
        Get build for the running task.

        :return: build object for task.
        """
        return self._api.build_by_id(self.build_id)

    def get_version(self):
        """
        Get version for the running task.

        :return: version object for task.
        """
        return self._api.version_by_id(self.version_id)


class Host(_BaseEvergreenObject):
    """Representation of an Evergreen host."""

    def __init__(self, json, api):
        """
        Create an instance of an evergreen host.
        """
        super(Host, self).__init__(json, api)

    @property
    def running_task(self):
        return RunningTask(self.json['running_task'], self._api)

    def get_build(self):
        """
        Get the build for the build using this host.

        :return: build for task running on this host.
        """
        return self.running_task.get_build()

    def get_version(self):
        """
        Get the version for the task using this host.

        :return: version for task running on this host.
        """
        return self.running_task.get_version()

    def __str__(self):
        return '{host_id}: {distro_id} - {status}'.format(
            host_id=self.host_id, distro_id=self.distro['distro_id'], status=self.status)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

from glob import glob
from os.path import basename
from os.path import splitext

from setuptools import find_packages
from setuptools import setup


with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='evergreen.py',
    version='0.1.4',
    license='Apache License, Version 2.0',
    description='Python client for the Evergreen API',
    long_description=long_description,
    author='David Bradford',
    author_email='david.bradford@mongodb.com',
    url='https://github.com/evergreen-ci/evergreen.py',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    py_modules=[splitext(basename(path))[0] for path in glob('src/*.py')],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],
    install_requires=[
        'backports.functools_lru_cache==1.5;python_version<"3.3"',
        'Click==7.0',
        'PyYAML==3.13',
        'requests==2.21.0',
    ],
    entry_points='''
        [console_scripts]
        evg_api=evergreen.cli.main:main
    ''',
)
